@@ -35,7 +35,8 @@ import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import javax.faces.context.FacesContext;
+import jakarta.faces.context.FacesContext;
+
 import java.io.IOException;
 import java.lang.invoke.MethodHandles;
 
@@ -53,7 +54,7 @@ public class SplitLayoutRenderer<T extends AbstractUISplitLayout> extends Render
 
   @Override
   public void decodeInternal(final FacesContext facesContext, final T component) {
-    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("javax.faces.source");
+    final String sourceId = facesContext.getExternalContext().getRequestParameterMap().get("jakarta.faces.source");
     final String clientId = component.getClientId() + SUFFIX_SIZES;
     if (clientId.equals(sourceId)) {
       // only decode and update layout at resize request
